@@ -45,7 +45,7 @@ import github.PaginatedList
 
 class Commit(github.GithubObject.CompletableGithubObject):
     """
-    This class represents Commits. The reference can be found here http://developer.github.com/v3/git/commits/
+    This class represents Commits. The reference can be found here https://docs.github.com/en/rest/reference/git#commits
     """
 
     def __repr__(self):
@@ -139,7 +139,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         position=github.GithubObject.NotSet,
     ):
         """
-        :calls: `POST /repos/:owner/:repo/commits/:sha/comments <http://developer.github.com/v3/repos/comments>`_
+        :calls: `POST /repos/{owner}/{repo}/commits/{sha}/comments <https://docs.github.com/en/rest/reference/repos#comments>`_
         :param body: string
         :param line: integer
         :param path: string
@@ -162,7 +162,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         if position is not github.GithubObject.NotSet:
             post_parameters["position"] = position
         headers, data = self._requester.requestJsonAndCheck(
-            "POST", self.url + "/comments", input=post_parameters
+            "POST", f"{self.url}/comments", input=post_parameters
         )
         return github.CommitComment.CommitComment(
             self._requester, headers, data, completed=True
@@ -176,7 +176,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         context=github.GithubObject.NotSet,
     ):
         """
-        :calls: `POST /repos/:owner/:repo/statuses/:sha <http://developer.github.com/v3/repos/statuses>`_
+        :calls: `POST /repos/{owner}/{repo}/statuses/{sha} <https://docs.github.com/en/rest/reference/repos#statuses>`_
         :param state: string
         :param target_url: string
         :param description: string
@@ -204,7 +204,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
             post_parameters["context"] = context
         headers, data = self._requester.requestJsonAndCheck(
             "POST",
-            self._parentUrl(self._parentUrl(self.url)) + "/statuses/" + self.sha,
+            f"{self._parentUrl(self._parentUrl(self.url))}/statuses/{self.sha}",
             input=post_parameters,
         )
         return github.CommitStatus.CommitStatus(
@@ -213,47 +213,47 @@ class Commit(github.GithubObject.CompletableGithubObject):
 
     def get_comments(self):
         """
-        :calls: `GET /repos/:owner/:repo/commits/:sha/comments <http://developer.github.com/v3/repos/comments>`_
+        :calls: `GET /repos/{owner}/{repo}/commits/{sha}/comments <https://docs.github.com/en/rest/reference/repos#comments>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.CommitComment.CommitComment`
         """
         return github.PaginatedList.PaginatedList(
             github.CommitComment.CommitComment,
             self._requester,
-            self.url + "/comments",
+            f"{self.url}/comments",
             None,
         )
 
     def get_statuses(self):
         """
-        :calls: `GET /repos/:owner/:repo/statuses/:ref <http://developer.github.com/v3/repos/statuses>`_
+        :calls: `GET /repos/{owner}/{repo}/statuses/{ref} <https://docs.github.com/en/rest/reference/repos#statuses>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.CommitStatus.CommitStatus`
         """
         return github.PaginatedList.PaginatedList(
             github.CommitStatus.CommitStatus,
             self._requester,
-            self._parentUrl(self._parentUrl(self.url)) + "/statuses/" + self.sha,
+            f"{self._parentUrl(self._parentUrl(self.url))}/statuses/{self.sha}",
             None,
         )
 
     def get_combined_status(self):
         """
-        :calls: `GET /repos/:owner/:repo/commits/:ref/status/ <http://developer.github.com/v3/repos/statuses>`_
+        :calls: `GET /repos/{owner}/{repo}/commits/{ref}/status/ <http://docs.github.com/en/rest/reference/repos#statuses>`_
         :rtype: :class:`github.CommitCombinedStatus.CommitCombinedStatus`
         """
-        headers, data = self._requester.requestJsonAndCheck("GET", self.url + "/status")
+        headers, data = self._requester.requestJsonAndCheck("GET", f"{self.url}/status")
         return github.CommitCombinedStatus.CommitCombinedStatus(
             self._requester, headers, data, completed=True
         )
 
     def get_pulls(self):
         """
-        :calls: `GET /repos/:owner/:repo/commits/:sha/pulls <https://developer.github.com/v3/repos/commits/#list-pull-requests-associated-with-commit>`_
+        :calls: `GET /repos/{owner}/{repo}/commits/{sha}/pulls <https://docs.github.com/en/rest/reference/repos#list-pull-requests-associated-with-a-commit>`_
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.PullRequest.PullRequest`
         """
         return github.PaginatedList.PaginatedList(
             github.PullRequest.PullRequest,
             self._requester,
-            self.url + "/pulls",
+            f"{self.url}/pulls",
             None,
             headers={"Accept": "application/vnd.github.groot-preview+json"},
         )
@@ -265,7 +265,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         filter=github.GithubObject.NotSet,
     ):
         """
-        :calls: `GET /repos/:owner/:repo/commits/:sha/check-runs <https://docs.github.com/en/rest/reference/checks#list-check-runs-for-a-git-reference>`_
+        :calls: `GET /repos/{owner}/{repo}/commits/{sha}/check-runs <https://docs.github.com/en/rest/reference/checks#list-check-runs-for-a-git-reference>`_
         :param check_name: string
         :param status: string
         :param filter: string
@@ -281,12 +281,12 @@ class Commit(github.GithubObject.CompletableGithubObject):
             url_parameters["check_name"] = check_name
         if status is not github.GithubObject.NotSet:
             url_parameters["status"] = status
-        if status is not github.GithubObject.NotSet:
+        if filter is not github.GithubObject.NotSet:
             url_parameters["filter"] = filter
         return github.PaginatedList.PaginatedList(
             github.CheckRun.CheckRun,
             self._requester,
-            self.url + "/check-runs",
+            f"{self.url}/check-runs",
             url_parameters,
             headers={"Accept": "application/vnd.github.v3+json"},
             list_item="check_runs",
@@ -296,7 +296,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         self, app_id=github.GithubObject.NotSet, check_name=github.GithubObject.NotSet
     ):
         """
-        :class: `GET /repos/:owner/:repo/commits/:ref/check-suites <https://docs.github.com/en/rest/reference/checks#list-check-suites-for-a-git-reference>`_
+        :class: `GET /repos/{owner}/{repo}/commits/{ref}/check-suites <https://docs.github.com/en/rest/reference/checks#list-check-suites-for-a-git-reference>`_
         :param app_id: int
         :param check_name: string
         :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.CheckSuite.CheckSuite`
@@ -314,7 +314,7 @@ class Commit(github.GithubObject.CompletableGithubObject):
         return github.PaginatedList.PaginatedList(
             github.CheckSuite.CheckSuite,
             self._requester,
-            self.url + "/check-suites",
+            f"{self.url}/check-suites",
             parameters,
             headers=request_headers,
             list_item="check_suites",
